@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef EXPORTADDRESSBOOKINTERFACEIMPL_H
-#define EXPORTADDRESSBOOKINTERFACEIMPL_H
+#pragma once
 
 #include "exportaddressbookjobinterface.h"
 #include "pimdataexportercore_private_export.h"
@@ -30,4 +29,3 @@ protected:
     Q_REQUIRED_RESULT QString createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree) override;
 };
 
-#endif // EXPORTADDRESSBOOKINTERFACEIMPL_H
