@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef IMPORTALARMJOBINTERFACE_H
-#define IMPORTALARMJOBINTERFACE_H
+#pragma once
 
 #include "abstractimportexportjob.h"
 #include "pimdataexportercore_private_export.h"
@@ -34,4 +33,3 @@ private:
     Q_REQUIRED_RESULT QString installConfigLocation() const;
 };
 
-#endif // IMPORTALARMJOBINTERFACE_H
