@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef IMPORTADDRESSBOOKJOBINTERFACETEST_H
-#define IMPORTADDRESSBOOKJOBINTERFACETEST_H
+#pragma once
 
 #include <QObject>
 class ImportAddressbookJobInterfaceTest : public QObject
@@ -19,4 +18,3 @@ private Q_SLOTS:
     void importAddressbook_data();
 };
 
-#endif // IMPORTADDRESSBOOKJOBINTERFACETEST_H
