@@ -132,7 +132,7 @@ KZip *Utils::openZip(const QString &filename, QString &errorMsg)
     const bool result = zip->open(QIODevice::ReadOnly);
     if (!result) {
         errorMsg = i18n("Archive cannot be opened in read mode.");
-        qCWarning(PIMDATAEXPORTERCORE_LOG) << "Impossible to open archive: " << filename;
+        qCWarning(PIMDATAEXPORTERCORE_LOG) << "Impossible to open archive: " << filename << "zip error : " << zip->errorString();
         delete zip;
         return nullptr;
     }
