@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,7 +23,7 @@ PimDataCommandLineOption::~PimDataCommandLineOption()
 
 void PimDataCommandLineOption::slotActivateRequested(const QStringList &arguments, const QString &workingDirectory)
 {
-    Q_UNUSED(workingDirectory);
+    Q_UNUSED(workingDirectory)
     if (!arguments.isEmpty()) {
         if (mParser.parse(arguments)) {
             handleCommandLine();
@@ -37,7 +37,7 @@ void PimDataCommandLineOption::createParser(const QApplication &app)
 {
     KAboutData aboutData(QStringLiteral("pimdataexporter"), i18n("PIM Data Exporter"),
                          QStringLiteral(PIMDATAEXPORTER_VERSION), i18n("PIM Data Exporter"), KAboutLicense::GPL_V2,
-                         i18n("Copyright © 2012-2020 pimdataexporter authors"));
+                         i18n("Copyright © 2012-2021 pimdataexporter authors"));
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     KAboutData::setApplicationData(aboutData);
     aboutData.setupCommandLine(&mParser);
